Agent

Struct Agent 

pub struct Agent { /* private fields */ }
Configuration for a custom subagent.

Agents allow you to define specialised assistants with custom prompts, models, and tool access. They are passed to the Claude CLI via the --agents flag.

Example

use clauders::{Agent, Model};

let agent = Agent::new("Reviews code for issues", "You are a code reviewer")
    .with_model(Model::Sonnet)
    .with_tools(["Read", "Grep"]);

Implementations

Source

impl Agent

pub fn new(description: impl Into<String>, prompt: impl Into<String>) -> Self

Creates a new agent with the given description and system prompt.

pub fn description(&self) -> &str

The description of this agent.

pub fn prompt(&self) -> &str

The prompt of this agent.

pub fn model(&self) -> Option<&Model>

The model of this agent, if set.

pub fn set_model(&mut self, model: impl Into<Model>)

Sets the model for this agent.

pub fn with_model(self, model: impl Into<Model>) -> Self

Sets the model for this agent.

pub fn tools(&self) -> &[String]

The tools this agent can use.

pub fn set_tools(&mut self, tools: impl IntoIterator<Item = impl Into<String>>)

Sets the tools this agent can use.

pub fn with_tools( self, tools: impl IntoIterator<Item = impl Into<String>>, ) -> Self

Sets the tools this agent can use.