pub struct Agent { /* private fields */ }Expand description
Configuration for a custom subagent.
Agents allow you to define specialised assistants with custom prompts,
models, and tool access. They are passed to the Claude CLI via the
--agents flag.
Example
use clauders::{Agent, Model};
let agent = Agent::new("Reviews code for issues", "You are a code reviewer")
.with_model(Model::Sonnet)
.with_tools(["Read", "Grep"]);Implementations
Sourceimpl Agent
impl Agent
Sourcepub fn new(description: impl Into<String>, prompt: impl Into<String>) -> Self
pub fn new(description: impl Into<String>, prompt: impl Into<String>) -> Self
Creates a new agent with the given description and system prompt.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
The description of this agent.
Sourcepub fn with_model(self, model: impl Into<Model>) -> Self
pub fn with_model(self, model: impl Into<Model>) -> Self
Sets the model for this agent.
Sourcepub fn set_tools(&mut self, tools: impl IntoIterator<Item = impl Into<String>>)
pub fn set_tools(&mut self, tools: impl IntoIterator<Item = impl Into<String>>)
Sets the tools this agent can use.
Sourcepub fn with_tools(
self,
tools: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_tools( self, tools: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Sets the tools this agent can use.